@@ -1,4 +1,6 @@
 package Ark::Plugin::Encoding::Null;
+use strict;
+use warnings;
 use Ark::Plugin;
 
 sub prepare_encoding { };
